/**
 * A helper class that allows us to accept Pipe implementations.
 */
var PipeTransformType = (function () {
    function PipeTransformType() {
    }
    PipeTransformType.prototype.transform = function (value) {
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        throw new Error("Do not use this class from user code. This class is only to support the SVOGV infrastructure.");
    };
    return PipeTransformType;
}());
export { PipeTransformType };
/**
 * The Format decorator. Provide the name of a Pipe that's being used by the
 * dynamic pipe formatter. Hence, the form does not need to apply forms manually.
 * The reason is that you may create forms automatically and hence can't write
 * actual Pipes somewhere. This applies especially if you create a table and loop
 * through properties.
 *
 * @param readonly      Optional, default is true.
 * @param description   A tooltip that can be used optionally.
 */
export function Format(pipeName, pipeParams) {
    if (pipeParams === void 0) { pipeParams = null; }
    // the original decorator
    function formatInternal(target, property) {
        formatInternalSetup(target, property.toString(), pipeName);
    }
    // return the decorator
    return formatInternal;
}
export function formatInternalSetup(target, key, pipeName, pipeParams) {
    if (pipeParams === void 0) { pipeParams = null; }
    // create a helper property to transport a meta data value
    Object.defineProperty(target, "__hasPipe__" + key, {
        value: pipeName,
        enumerable: false,
        configurable: false
    });
    if (pipeParams && pipeParams.length) {
        Object.defineProperty(target, "__pipeParams__" + key, {
            value: pipeParams,
            enumerable: false,
            configurable: false
        });
    }
}

//# sourceMappingURL=hint-format.decorator.js.map
