var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Injectable } from '@angular/core';
import { FormValidatorService } from './formvalidator.service';
import { displayInternalSetup, displayGroupInternalSetup, hiddenInternalSetup, formatInternalSetup, placeholderInternalSetup, compareInternalSetup, maxLengthInternalSetup, minLengthInternalSetup, patternInternalSetup, stringLengthInternalSetup, emailInternalSetup, rangeInternalSetup, readonlyInternalSetup, requiredInternalSetup } from '../decorators/index';
/**
 * A JSON object can describe the form. That way you can create the form and their behavior on the server.
 *
 * The form's description is an array, where each element describes one field:
 *
 * ```
 * [
 *   "fieldname": {
 *       "display": {
 *          "name": string;
 *          "order": number;
 *          "description": string
 *       },
 *       "displaygroup": {
 *          "name": string;
 *          "order": number;
 *          "description": string
 *       },
 *       "format": {
 *          "pipeName": any;
 *          "pipeParams": any[]
 *       }
 *       // ...
 *    }
 * ]
 * ```
 *
 * The properties are the same as the decorators. @see FormValidatorModel for the describing type.
 *
 */
var FormValidatorFromJsonService = (function () {
    function FormValidatorFromJsonService(formValidatorService) {
        this.formValidatorService = formValidatorService;
    }
    FormValidatorFromJsonService.prototype.build = function (json) {
        var target = {};
        // convert json (indexed object ==> array ==> object properties)
        var fields = Object.keys(json);
        fields.forEach(function (field) {
            var types = Object.keys(json[field]);
            types.forEach(function (type) {
                switch (type) {
                    case 'display':
                        displayInternalSetup(target, field, json[field][type]['name'], json[field][type]['order'] ? +field[type]['order'] : 0, json[field][type]['description']);
                        break;
                    case 'displayGroup':
                        displayGroupInternalSetup(target, field, json[field][type]['name'], json[field][type]['order'] ? +field[type]['order'] : 0, json[field][type]['description']);
                        break;
                    case 'format':
                        formatInternalSetup(target, field, json[field][type]['pipeName'], json[field][type]['pipeParams']);
                        break;
                    case 'hidden':
                        hiddenInternalSetup(target, field, json[field][type]['hidden'] || !!field[type]['hidden']);
                        break;
                    case 'readonly':
                        readonlyInternalSetup(target, field, json[field][type]['readonly'] || !!field[type]['readonly']);
                        break;
                    case 'placeHolder':
                        placeholderInternalSetup(target, field, json[field][type]['name']);
                        break;
                    case 'compare':
                        compareInternalSetup(target, field, json[field][type]['fieldToCompare'], json[field][type]['msg']);
                        break;
                    case 'maxlength':
                        maxLengthInternalSetup(target, field, +json[field][type]['max'], json[field][type]['msg']);
                        break;
                    case 'minlength':
                        minLengthInternalSetup(target, field, +json[field][type]['min'], json[field][type]['msg']);
                        break;
                    case 'pattern':
                        patternInternalSetup(target, field, json[field][type]['pattern'], json[field][type]['msg']);
                        break;
                    case 'stringLength':
                        stringLengthInternalSetup(target, field, +json[field][type]['min'], +json[field][type]['max'], json[field][type]['msg']);
                        break;
                    case 'email':
                        emailInternalSetup(target, field, json[field][type]['msg']);
                        break;
                    case 'range':
                        rangeInternalSetup(target, field, json[field][type]['from'], json[field][type]['to'], json[field][type]['msg']);
                        break;
                    case 'required':
                        requiredInternalSetup(target, field, json[field][type]['msg']);
                        break;
                }
            });
        });
        return this.formValidatorService.build(target);
    };
    return FormValidatorFromJsonService;
}());
FormValidatorFromJsonService = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [FormValidatorService])
], FormValidatorFromJsonService);
export { FormValidatorFromJsonService };

//# sourceMappingURL=formvalidator-fromjson.service.js.map
