var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
import { Injectable, Inject } from '@angular/core';
import { Validators, FormBuilder } from '@angular/forms';
import { validateRange } from './validators/range.validator';
import { validateCompare } from './validators/compare.validator';
/**
 * The form validation service creates a FormGroup object from a viewmodel. If the viewmodel
 * has been decorated with validation decorators the validators are created accordingly.
 */
var FormValidatorService = (function () {
    function FormValidatorService(fb) {
        this.fb = fb;
    }
    FormValidatorService.prototype.build = function (target) {
        var valGroup = {};
        var errGroup = {};
        var form;
        var targetInstance;
        if (target) {
            // the cast is just to suppress TS errors and shows it's intentionally
            try {
                targetInstance = new target();
            }
            catch (ex) {
                console.error('Invalid viewmodel for FormValidatorService');
            }
        }
        if (targetInstance) {
            for (var propName in targetInstance) {
                var validators = new Array();
                var errmsgs = new Object();
                var isRequired = "__isRequired__" + propName in target.prototype;
                if (isRequired) {
                    errmsgs['required'] = target.prototype["__errRequired__" + propName];
                    validators.push(Validators.required);
                }
                var hasMaxLength = "__hasMaxLength__" + propName in target.prototype;
                if (hasMaxLength) {
                    errmsgs['maxlength'] = target.prototype["__errMaxLength__" + propName];
                    var maxLength = parseInt(target.prototype["__hasMaxLength__" + propName], 10);
                    validators.push(Validators.maxLength(maxLength));
                }
                var hasMinLength = "__hasMinLength__" + propName in target.prototype;
                if (hasMinLength) {
                    errmsgs['minlength'] = target.prototype["__errMinLength__" + propName];
                    var minLength = parseInt(target.prototype["__hasMinLength__" + propName], 10);
                    validators.push(Validators.minLength(minLength));
                }
                var hasPattern = "__hasPattern__" + propName in target.prototype;
                if (hasPattern) {
                    errmsgs['pattern'] = target.prototype["__errPattern__" + propName];
                    var pattern = new RegExp(target.prototype["__hasPattern__" + propName]);
                    validators.push(Validators.pattern(pattern));
                }
                var hasRangeFrom = "__hasRangeFrom__" + propName in target.prototype;
                var hasRangeTo = "__hasRangeTo__" + propName in target.prototype;
                if (hasRangeFrom || hasRangeTo) {
                    errmsgs['range'] = target.prototype["__errRange__" + propName];
                    var f = Number(target.prototype["__hasRangeFrom__" + propName]);
                    var t = Number(target.prototype["__hasRangeTo__" + propName]);
                    if (!f && !t) {
                        // If NaN assume Date
                        f = Date.parse(f.toString());
                        t = Date.parse(t.toString());
                    }
                    validators.push(validateRange(f, t));
                }
                var hasCompare = "__hasCompareProperty__" + propName in target.prototype;
                if (hasCompare) {
                    errmsgs['compare'] = target.prototype["__errCompareProperty__" + propName];
                    var compare = target.prototype["__withCompare__" + propName];
                    validators.push(validateCompare(compare));
                }
                if (validators.length === 0) {
                    // even if there is no validator we need to add the property to the group
                    valGroup[propName] = [target[propName]];
                }
                if (validators.length === 1) {
                    valGroup[propName] = [target[propName] || '', validators[0]];
                }
                if (validators.length >= 1) {
                    valGroup[propName] = [target[propName] || '', Validators.compose(validators)];
                }
                errGroup[propName] = errmsgs;
            }
            // create form group
            form = this.fb.group(valGroup);
            // forward the model to the editors for easy access to other decorators
            // the cast is just to suppress TS errors and shows it's intentionally
            form['__editorModel__'] = targetInstance;
            // register controls and add messages
            for (var propName in errGroup) {
                var ctrl = form.controls[propName];
                if (!ctrl) {
                    continue; // control might not be in the form
                }
                form.controls[propName]['messages'] = errGroup[propName];
            }
        }
        // return FormGroup for immediate usage
        return form;
    };
    return FormValidatorService;
}());
FormValidatorService = __decorate([
    Injectable(),
    __param(0, Inject(FormBuilder)),
    __metadata("design:paramtypes", [FormBuilder])
], FormValidatorService);
export { FormValidatorService };

//# sourceMappingURL=formvalidator.service.js.map
